@@ -4,10 +4,10 @@ __docformat__ = 'epytext'
 
 from django.contrib import admin
 from publications.models import Type, List, Publication
-from publicationadmin import PublicationAdmin
-from typeadmin import TypeAdmin
-from listadmin import ListAdmin
-from orderedmodeladmin import OrderedModelAdmin
+from .publicationadmin import PublicationAdmin
+from .typeadmin import TypeAdmin
+from .listadmin import ListAdmin
+from .orderedmodeladmin import OrderedModelAdmin
 
 admin.site.register(Type, TypeAdmin)
 admin.site.register(List, ListAdmin)
