@@ -2,4 +2,4 @@ __license__ = 'MIT License <http://www.opensource.org/licenses/mit-license.php>'
 __author__ = 'Lucas Theis <lucas@theis.io>'
 __docformat__ = 'epytext'
 
-from import_bibtex import import_bibtex
+from .import_bibtex import import_bibtex
